cap log close
clear all
set more off, permanently
set matsize 11000
set maxvar 32767

global rootDir "ENTER_PATH_HERE"

/*******************************************************************************
Program: classifyNeighborsUScountiesN3.do
Author: Eyal Frank

This program demonstrates how to use the classifyNeighbors program I wrote. It 
applies it to the contiguous U.S. counties and returns a file with each county 
matched with its nearest neighbor, second degree neighbor, and third degree 
neighbor. A full description of the program can be found on: 
www.eyalfrank.com/classifying-neighboring-spatial-units/
*******************************************************************************/

do "$rootDir/classifyNeighborsPRG.do "

* Set the maximum neighboring degree parameter
local maxNeighborDegree = 3

* Declare the file names 
local coordinatesFile = "countiesCentroidsCoordinates.csv"
local distanceFile = "CountiesDistanceMatrix.csv"
local areaFile = "CountyAreaTable.csv"
local neighbroingLinesFile = "neighboringCounties.csv"

* Columns that need to be kept as strings. 
local coordinatesKEEP_STRINGS = "6"
local distanceKEEP_STRINGS = "10 21"
local areaKEEP_STRINGS = "2"

* Define the variables that identify the spatial units 
local geoid = "geoid"
local idVar = "fipscode"

* Define variable names 
local longitudeVar = "longitude"
local latitudeVar = "latitude"
local distanceVar = "distance"
local areaVar = "area_km_sq"

* Define units 
local distanceUnit = "meters"
local areaUnit = "squared kilometers"


local PATH_GIS = "dataGIS" 

classifyNeighbors `coordinatesFile' /// 
                  `longitudeVar' /// 
                  `latitudeVar' /// 
                  "`coordinatesKEEP_STRINGS'" /// 
                  `distanceFile' /// 
                  "`distanceUnit'" /// 
                  `distanceVar' ///
                  "`distanceKEEP_STRINGS'" /// 
                  `areaFile' /// 
                  "`areaUnit'" /// 
                  `areaVar' /// 
                  "`areaKEEP_STRINGS'" /// 
                  `neighbroingLinesFile' /// 
                  "$rootDir" /// 
                  `PATH_GIS' /// 
                  `geoid' /// 
                  `idVar' /// 
                  `maxNeighborDegree' 


save "$rootDir/classifyNeighborsUScountiesN3.dta", replace


